``Spine plugin for Django``

Description
===========

Requirements
============
* django
* django-subcommand

Features
========


Setup
=====

::

    $ pip install django-spine


Installation
~~~~~~~~~~~~

edit settings.py ::

    INSTALLED_APPS = (
        "subcommand",
        "spine",
        'compressor',
    )


History
========
0.x (2012-xx-xx)
~~~~~~~~~~~~~~~~
* first release

License
=======
MIT License
